/**
 *  Slidedeck script for hotspot feature.
 */

jQuery(function($){

    SlidedeckHotspots = {

        uniqueViews : ( typeof slideckVars !== 'undefined' && slideckVars.unique_pageviews == 1 && typeof Storage !== 'undefined' ) ? true : false,
        windowFocused : true,
        expireAfter : 86400,

        init : function()
        {
            this.expireLocalStorage();
            this.setWindowFocusedValue();
            this.onPageLoad();
            this.addRemoveVisibleClass();
            this.events();
        },

        events : function()
        {
            var _this = this, $this ,post_id ,index, dd, $dd, $slider, caption, $slide, tagName, zeroBasedSlideIndex;

            $('.slidedeck-frame').on( 'click', 'a' , function(e){

                $this = $(this);
                $slide = $(this).closest('li');
                $slide = $slide.length ? $slide : $(this).closest('dd');

                if( $.isEmptyObject($slide) || ! $slide.length ) return;

                tagName = $slide.prop("tagName");

                index = $slide.prop("tagName") == 'DD' ? $slide.index('dd') : $slide.index('li');

                $slider = $(this).closest('.slidedeck-frame');
                post_id = _this.getPostID( $slider );
                caption = _this.getCaption( $slider, index );

                _this.saveSlide( index, post_id, 'click', caption );

            });

            $( window ).on( 'slidedeckChange', function( e, slides, index )
            {
                dd = slides[index];
                $dd = $(dd);
                $slider = ( ! $.isEmptyObject($dd) && $dd.length ) ? $dd.closest('.slidedeck-frame') : false;
                zeroBasedSlideIndex = index > 0 ? index - 1 : 0;

                if( ! $slider ) return;
                post_id = _this.getPostID($slider);

                //If its currently in the viewport
                if( $slider.hasClass('slidedeck-viewport') && _this.windowFocused ){
                    caption = _this.getCaption( $slider, zeroBasedSlideIndex );
                    _this.saveSlide( zeroBasedSlideIndex, post_id, 'view', caption );
                }

            });

            $( window ).on( 'slideckCycleChange', function( e, isNext, zeroBasedSlideIndex, slideElement )
            {
                $li = $(slideElement);
                $slider = ( ! $.isEmptyObject($li) && $li.length ) ? $li.closest('.slidedeck-frame') : false;

                if( ! $slider ) return;

                post_id = _this.getPostID($slider);

                //If its currently in the viewport
                if( $slider.hasClass('slidedeck-viewport') && _this.windowFocused ){
                    caption = _this.getCaption( $slider, zeroBasedSlideIndex );
                    _this.saveSlide( zeroBasedSlideIndex, post_id, 'view' , caption );
                }
            });

        },

        /**
         * The key will be removed after the given time, so the visited can again be
         * considered as new visiter.
         * @return null
         */
        expireLocalStorage : function()
        {
            if( typeof(Storage) === "undefined" ) return;

            var key = 'slidedeck_stats_timestamp',
                savedTime = localStorage.getItem( key ),
                currentTime = new Date().getTime().toString(),
                timeSavedSince;

            if( $.isEmptyObject(savedTime) ){
                localStorage.setItem( key , currentTime );
            }
            else{
                timeSavedSince = ( currentTime - savedTime ) / 1000; //in seconds

                if( timeSavedSince > this.expireAfter ){
                    localStorage.setItem( key , currentTime );
                    localStorage.removeItem("slidedeck_slides_data");
                }
            }
        },

        getCaption : function( $slider, index )
        {
            var $caption,
                $captionInner,
                caption = '',
                $captionLink,
                $slide = $slider.find('ul.slidedeck > li');

            $slide = $slide.length ? $slide.eq(index) : $slider.find('dl.slidedeck > dd').eq(index);

            if( ! $slide.length ) return;

            //Lens Classic,lens-tool-kit, block-title, lens-fashion,
            $caption = $slide.find('.sd2-slide-title-inner');

            if( $caption.length ){ //Lens Classic, lens-tool-kit
              caption = $caption.text();
            }

            if( typeof caption === 'undefined' ) return '';

            return caption ? $.trim(caption) : '';

        },

        setWindowFocusedValue : function(){
            _this = this;
            window.onfocus = function() {
                _this.windowFocused = true;
            };
            window.onblur = function() {
                _this.windowFocused = false;
            };
        },

        addRemoveVisibleClass : function(){
            $(window).on( "scroll", function(){
                $('.slidedeck-frame').removeClass('slidedeck-viewport');
                $('.slidedeck-frame:in-viewport').each(function(index, el) {
                    $(this).addClass('slidedeck-viewport');
                });
            });
        },

        /**
         * Save the first image and the slider on page load because its above the fold
         * @return {[type]} [description]
         */
        onPageLoad : function(){

            var $slider       = $('.slidedeck-frame').eq(0),
                firstSliderID = this.getPostID( $slider ),
                caption       = this.getCaption( $slider, 0 );

            this.saveSlide( 0 , firstSliderID, 'view' );
        },

        getPostID : function( $el ){
            return $el.attr('id').match(/\d+/)[0];
        },


        isSlideStored : function( index, post_id, action ){

            var arrayObject = this.getStoredData();

            if( ! arrayObject.length ) return;

            var hasIt = false;
            /**
             * Will contain the internal array
             * the structure would be like [ index , post_id , action, time ]
             */
            var thisArray;

            for( var i = 0 ; i < arrayObject.length; i++ ){
                if( arrayObject[i].length )
                {
                    thisArray = arrayObject[i];
                    if( thisArray[0] == index && thisArray[1] == post_id && thisArray[2] == action ){
                        hasIt = true; break;
                    }
                }
            }
            return hasIt;
        },

        storeSlide : function( index , post_id , action ){

            //empty array
            var dataToBeSaved;
            var recievedData = [ index , post_id , action, new Date().getTime().toString() ];

            //Get
            var storedData = this.getStoredData();

            //Push & Set
            if( ! storedData ){ //when there is nothing stored
                dataToBeSaved = [ recievedData ];
            }
            else if( ! this.isSlideStored( index, post_id, action ) ){ //when the index is not stored
                storedData.push( recievedData );
                dataToBeSaved = storedData;
            }
            else{
                dataToBeSaved = storedData;
            }

            //Store
            localStorage.setItem( "slidedeck_slides_data" , JSON.stringify( dataToBeSaved ) ); //convert object => string

        },

        getStoredData : function(){
           var storedData = localStorage.getItem("slidedeck_slides_data");
               storedData = ! $.isEmptyObject(storedData) ? JSON.parse( storedData ) : false; //convert string => object
           return storedData;
        },

        saveSlide : function( index, post_id, action, caption ){

            if( this.uniqueViews ){
                if( ! this.isSlideStored( index , post_id, action ) ){
                    this.save( [ [ index , post_id , action, caption ] ] );
                    this.storeSlide( index , post_id, action );
                }
            }
            else{
                this.save( [ [ index , post_id, action, caption  ] ] );
            }

        },

        /**
         * Saved the slide post id and image url clicked by the user.
         * @param slides object the structure should be [ [ index , post_id  ] , ... ]
         * @return null
         */
        save : function( slides ){

            if( typeof slideckVars === 'undefined' || ! slides.length ) return;

            $.ajax({
                url: slideckVars.ajax_url,
                type: 'POST',
                dataType: 'json',
                data: {
                    'action' : 'slidedeck_update_hotspot',
                    'slides' : slides,
                },
            })
            .done(function( resp ) {
                console.log("success");
            })
            .fail(function( resp ) {
                console.log("error");
            });
        },
    };

    SlidedeckHotspots.init();

});