
jQuery(function($){

	"use strict";

	var SlidedeckTiledIframe = {
		Models : {},
		Views : {}
	};

	/*==============================
	      		 Tiled
	===============================*/

	SlidedeckTiledIframe.Models.Tiled = Backbone.Model.extend({

	    defaults: {
			php_function         : '',
			post_id              : '',
			slide_id  	         : '',
			perPosX 	         : '',
			perPosY 	         : '',
			zindex 				 : ''
	    },

	});

	SlidedeckTiledIframe.Views.Tiled = Backbone.View.extend({

	    el : '.lens-tiled',

	    events: {
	    	'click .sdt-add-opacity' : 'addOpacity',
	    	'click .sdt-save-layers' : 'save',
	    },

	    initialize: function(){
	    	this.makeDraggable();
	    	$(window).on( 'load', this.addImageCSS );
	    },

	    makeDraggable : function(){

	    	var _this = this, $this, position, positions;

	    	var $layers = $('.sdt-slide-layer');

	    	var count = 1;

	    	$layers.draggable({
    		  start : function( event, ui ){
    		  	$(this).css( "z-index", count++ );
    		  },
			  stop: function( event, ui )
			  {
		  		position = ui.position;

		  		positions =  _this.convertInPercentage( ui.position.left, ui.position.top );

		  		$(this)
		  		.data( 'z-index' , $(this).css('z-index') )
		  		.data( 'slide-id' , $(this).closest('.slide').data('slide-id') )
		  		.data( 'per-position-x' , positions[0] )
		  		.data( 'per-position-y' , positions[1] );

		  		$('button.sdt-save-layers').prop( 'disabled', false ).text("Save");
			  }
			});
	    },

	    addImageCSS : function(){

	    	var $slidedeck = $('.lens-tiled');
	    	var layerWidth, slidedeckWidth, widthInPercentage, left, top, zIndex;

	    	$slidedeck.each(function(){

	    		slidedeckWidth = $(window).width();

	    		$(this).find('.sdt-slide-layer').each(function(){

					layerWidth        = $(this).find('img').attr('width');
					widthInPercentage = ( layerWidth / slidedeckWidth ) * 100;
					left              = $(this).data('position-x') > -1 ? $(this).data('position-x') : 20;
					top               = $(this).data('position-y') > -1 ? $(this).data('position-y') : 20;
					zIndex            = $(this).data('z-index') ? $(this).data('z-index') : 20;
                                    
	    			$(this).css( {
	    				'width' : widthInPercentage + '%',
	    				'z-index' : zIndex,
	    				'left' : left + '%',
	    				'top' : top + '%'
	    			});

	    		});
	    	});


	    },

	    convertInPercentage : function( posX, posY )
	    {
	    	var $slider = $('.slide'),
	    		decimalPlace = 10000000,
	    		x = ( 100 * posX ) / $slider.width() ,
	    		y = ( 100 * posY ) / $slider.height();

	    		x = x < 0 ? 0 : Math.round( x * decimalPlace ) / decimalPlace;
	    		y = y < 0 ? 0 : Math.round( y * decimalPlace ) / decimalPlace;

	    	return [ x, y ];
	    },

	    addOpacity : function(e){
	    	var $this = $(e.currentTarget);
	    	e.preventDefault();

	    	var $colors = [ 'rgba(128, 0, 128, 0.29)', 'rgba(68, 68, 68, 0.35)', 'rgba(255, 0, 0, 0.18)', 'rgba(255, 255, 0, 0.28)' , 'rgba(0, 128, 0, 0.38)' ];
	    	var $thisSlide = $this.closest('.slide');

	    	if( $this.hasClass('active') ){
	    		$this.text("Add Opacity");
	    		$this.removeClass('active');
	    		$thisSlide.find('.sdt-slide-layer').each(function( index, el ){
	    			$(this).css( {
	    				'background-color' : 'transparent',
	    				'border' : 'none'
	    			});
	    		});
	    	}
	    	else{
	    		$this.text("Remove Opacity");
	    		$this.addClass('active');
	    		$thisSlide.find('.sdt-slide-layer').each(function( index, el ){
	    			$(this).css({
	    				'background-color' : $colors[index],
	    				'border' : '2px dotted #ccc'
	    			});
	    		});
	    	}
	    },

	    save : function(e)
	    {
	    	var $this = $(e.currentTarget);
	    	var $slidedeck = $('.lens-tiled');
	    	var $layer;
	    	var layers = [];

	    	$slidedeck.find('.slide').each(function(){
	    		$(this).find('.sdt-slide-layer').each(function(){
	    			if( $(this).data('slide-id') ){
	    				layers.push({
	    					'layer'          : $(this).data('layer'),
	    					'per_cordinates' : [ $(this).data('per-position-x') , $(this).data('per-position-y') ],
	    					'z_index'        : $(this).data('z-index'),
	    					'slide_id'       : $(this).data('slide-id')
	    				});
	    			}
	    		});
	    	});

	    	var ajaxData = {
	    		'action' : 'sdt_save_layers',
	    		'layers' : layers
	    	};

	    	$this.text("Saving...").prop('disabled', true);

	    	console.log(ajaxData);

	    	$.ajax({
	    		url: slidedeckTiledAdminURL,
	    		type: 'POST',
	    		dataType: 'json',
	    		data: ajaxData,
	    	})
	    	.done(function( resp ){
    			console.log(resp);
	    	})
	    	.always(function(){
	    		$this.text("Saved");
	    	});

	    },


	});


	SlidedeckTiledIframe.Tiled = new SlidedeckTiledIframe.Views.Tiled( { model : new SlidedeckTiledIframe.Models.Tiled() } );

});
