(function($){
    var titleClasses;
	if($('#slidedeck-preview').length > 0){
	   $('#slidedeck-preview').on('load', function() {
        	titleClasses = $('#slidedeck-preview').contents().find('.sd2-slide-titles-inner').attr('class').split(' '); }); 
	} else {
		titleClasses = $('.slidedeck-frame').contents().find('.sd2-slide-titles-inner').attr('class').split(' ');	
	}
    SlideDeckLens['titles'] = function(slidedeck){
        var self = this;
        var slidedeck = $(slidedeck);
        var slidedeckFrame = slidedeck.closest('.slidedeck-frame');
        var images = slidedeckFrame.find('img.slide-image');
        var deck = slidedeck.slidedeck();
        var deckElement = slidedeck;
        var navDeckElement = false;
        var navDeck = false;
        var mouseIsHoveringOverNav = false;
        var deckHeightAdjustment = 0;
        
        /**
         * Default options for the thumbnail navigation.
         * These are begging to be configurable*
         * 
         * *This means Jamie wants to add a slider or two...
         */
        var thumbnailLargeThreshold = 150; // larger than this gets the big thumbnail instead
        var thumbnailSpacing = 20;
        var thumbnailPercentageIntrinsic = 50; // A percentage ratio for the thumbnails (100 is close to square, 50 is close to 16:9)
        var maxButtonsPerPage = 5;
        var numberOfPages = 1;
        if( slidedeckFrame.hasClass('sd2-medium') ) {
            thumbnailSpacing = 16;
        }
        
        /**
         * Default options for the dot navigation.
         * For dots, there should be a max, and 20 is even high. 10 is the ideal max.
         * The dot spacing will shrink as certain thresholds are met, and depending on the size.
         */
        var maxDots = 20;
        var dotSpacing = 37;
        if( slidedeckFrame.hasClass('sd2-small') ) {
            dotSpacing = 25;
        }
        
        // After loaded callback
        deck.loaded(function( thedeck ){
            /**
             * Hide the slide content when a video play button is clicked.
             */
            deckElement.find('.play-video-alternative').click(function(event){
                $(this).parents('dd').addClass('show-video-wrapper');
                $(this).parents('dd').addClass('hide-slide-content');
            });
            
            /**
             * For this lens, the structure necessary deviates a bit too much.
             * When the viewer clicks the "Play Video" link, we'll trigger a click
             * on the generic play button in the template. 
             */
            $('.slide-type-video .play-video, .slide-type-video .play-video-alternative').bind( "click", function( event ){
                event.preventDefault();
                var parentSlide = $(this).parents('dd');
                var playButton = parentSlide.find('.video-wrapper .cover .play-video-button');
                playButton.trigger('click');
            } );
            
        });
        
        /**
         * Navigation function for the deck (when using dots)
         * 
         * Do not modify these values. If you must mess with them, they are
         * all set near the top of this class.
         */
        this.dotNavigation = function(){
            if( slidedeckFrame.hasClass('sd2-nav-dots') ) {
                var slideCount = slidedeck.find('dd.slide').length;
                var navHtml = '<div class="dot-nav-wrapper"><ul class="dot-nav"></ul></div>';
                
                /**
                 * Let's try to be sensible about the number
                 * of dots and the spacing. If we have over 10 dots,
                 * let's cut the spacing in half.
                 */    
                if( slideCount >= 10 ) dotSpacing = Math.round( dotSpacing / 2 );
                // Meh... why not?
                if( slideCount >= 15 ) dotSpacing = Math.round( dotSpacing / 2.5 );
                if( slideCount >= 20 ) dotSpacing = Math.round( dotSpacing / 2.8 );
                
                $(navHtml).appendTo(slidedeckFrame);
                
                // Adjust the deck height based on the dot navigation height.
                deckHeightAdjustment = slidedeckFrame.find('.dot-nav-wrapper').height();
                slidedeck.css({
                    height: slidedeck.height() - deckHeightAdjustment
                });
                slidedeck.find('dd').css({
                    height: slidedeck.height()
                });
                
                /**
                 * Create the dots, keeping in mind that the first dot has no 
                 * left margin and the following dots all have the defined value.
                 */
                var finalDotCount = Math.min( slideCount, maxDots );
                var dotNav = slidedeckFrame.find('.dot-nav');
                for( i = 0; i < finalDotCount; i++ ) {
                    
                    // If this is the first dot, no margin.
                    if( i == 0 ){
                        marginLeft = 0;
                    }else{
                        marginLeft = dotSpacing;
                    }
                    
                    // Append the actual element...
                    $('<li style="margin-left:' + marginLeft + 'px;"></li>').appendTo(dotNav);
                }
                
                // Fetch the newly appended dots...
                var navDots = dotNav.find('li');
                dotNav.css( 'width', Math.min( slideCount, maxDots ) * ( navDots.outerWidth() + dotSpacing ) - dotSpacing )
                dotNav.css( 'margin-left', -( dotNav.outerWidth() / 2) );
                navDots.eq( deck.current-1 ).addClass('accent-color-background active');
                // ADD CLICK FUNCTIONS
                navDots.bind('click', function(){
                    var $self = $(this);
                    deck.goTo(($self).index()+1);
                    navDots.removeClass('accent-color-background active');
                    $self.addClass('accent-color-background active');
                });
                
                // Add hover binding
                navDots.bind('mouseenter mouseleave', function( event ){
                    var elem = $(this);
                    if( event.type == 'mouseenter' ) {
                        elem.addClass('accent-color-background');
                    } else if( !elem.hasClass( 'active' ) ) {
                        elem.removeClass('accent-color-background');
                    }
                });

            }
        }

        /**
         * Navigation function for the deck (when using text buttons)
         * 
         * Do not modify these values. If you must mess with them, they are
         * all set near the top of this class.
         */
        this.buttonTextNavigation = function(){
            if( slidedeckFrame.hasClass('sd2-nav-text') ) {
                var slideCount = slidedeck.find('dd.slide').length;
                var navHtml = '<div class="button-nav"></div>';
                var appendedNav = $(navHtml).appendTo(slidedeckFrame);
                var navOuterWidth = parseInt( appendedNav.outerWidth() );
               
                var navArrowWidth = 34;
                var buttonsMargin = navArrowWidth + Math.round( thumbnailSpacing / 2 );
                var maxButtonsPerPage = 5;
                
                numberOfPages = Math.ceil( slideCount / maxButtonsPerPage );
                
                // If there's only one slide, don't do any thumbnails.
                if( slideCount < 2 ) return true;
                
                detectedIntrinsicHeight = slidedeckFrame[0].className.match(/sd2-thumbnail-height-([0-9]+)/);
                if( typeof(detectedIntrinsicHeight[1]) != 'undefined' ) {
                    thumbnailPercentageIntrinsic = parseInt( detectedIntrinsicHeight[1] );
                }
                
                if( maxButtonsPerPage >= slideCount ){
                    navArrowWidth = false;
                }
                
                // Create the button nav
                var buttonTextNav = slidedeckFrame.find('.button-nav');
                
                // Append the previous nav
                if( navArrowWidth ){
                    buttonTextNav.append('<a class="nav-arrow prev" href="#prev-page" style="width:' + navArrowWidth + 'px;"><span></span></a>');
                } else {
                    buttonsMargin = 0;
                }
                
                // Create the pages
                var indexCount = 0;
                buttonTextNav.append('<dl class="nav-slidedeck" style="width: auto; margin: 0 ' + ( buttonsMargin - Math.round( thumbnailSpacing / 2 ) ) + 'px;"></dl>');
                navDeckElement = slidedeckFrame.find('dl.nav-slidedeck');
                for( p = 1; p <= numberOfPages; p++ ){
                    
                    navDeckElement.append( '<dd class="sd-page"></dd>' );
                    var thisPage = slidedeckFrame.find('dl.nav-slidedeck dd:eq(' + ( p - 1 ) + ')');
                    
                    for( i = indexCount; i < Math.min( slideCount, maxButtonsPerPage ) * p; i++ ) {
                        var thumbnail = '<span class="nav-button"><div style="padding-top:' + thumbnailPercentageIntrinsic + '%; margin: 0">Foo</div></span>';
                        if( indexCount >= slideCount ) {
                            thumbnail = false;
                        }
                        
                        if( thumbnail ){
                            //alert(thumbnail);
                            $( thumbnail ).appendTo(thisPage);
                        }else{
                            $( '<span class="spacer"></span>' ).appendTo(thisPage);
                        }
                        
                        indexCount++;
                    }
                }
                
                /**
                 * Figure out the height of one thumbnail item, and then
                 * set the height of the nav deck.
                 */
               // alert(parseInt( buttonTextNav.find('.nav-button:first div').css('padding-top') ));
                var thumbnailHeight = Math.round( parseInt( buttonTextNav.find('.nav-button:first div').css('padding-top') ) );
                
                navDeck = slidedeckFrame.find('dl.nav-slidedeck').css({
                    height: 75
                }).slidedeck({
                    keys: false,
                    scroll: false,
                    cycle: slidedeck.slidedeck().options.cycle
                });
                
                // Adjust the deck height based on the thumbnail navigation height.
                deckHeightAdjustment = 75 + thumbnailSpacing;
                slidedeck.css({
                    height: slidedeck.height() - deckHeightAdjustment
                });
                slidedeck.find('dd').css({
                    height: slidedeck.height()
                });
                
                
                var buttons = buttonTextNav.find('.nav-button');
                
                // Append the next nav
                if( navArrowWidth ) {
                    buttonTextNav.append('<a class="nav-arrow next" href="#next-page" style="width:' + navArrowWidth + 'px;"><span></span></a>');
                }
                
                buttons.eq( deck.current-1 ).addClass('active');
                
                buttons.bind('click', function(){
                    var $self = $(this);
                    deck.goTo( ($self).index('.nav-button') +1 );
                });
                
                // Size the buttons appropriately.
                
                
                buttons.css({
                    width: ( 100 / ( Math.min( slideCount, maxButtonsPerPage ) ) ) + '%'
                });
                navDeckElement.find('span.spacer').css({
                    width: ( 100 / ( Math.min( slideCount, maxButtonsPerPage ) ) ) + '%'
                });
                
                // Only for IE - detect background image url and update style for DD element
                buttons.each(function( index ){
                    var image = false;
                    if( deck.slides.eq( index ).attr('data-thumbnail-src') ){
                        /**
                         * Use a large image if the thumbnail size is larger than the
                         * defined size. This is for speed and clarity :-)
                         */
                       
                            image = deck.slides.eq( index ).attr('data-thumbnail-src');
                       
                    }
                    
                    if( image ) {
                        var caption = $('.slide_'+ (index + 1)).find('.sd2-slide-title-inner').html();
                        $(this).addClass('sd2-no-image').find('div').append('<span class="sd2-number sd2-custom-title-font">' + ( caption ) + '</span>');
                        $(this).find('.sd2-number').css({
                            'line-height': 65 + 'px',
                            'font-size': ( 20 ) + 'px'
                        });
                    } else {
                        $(this).addClass('sd2-no-image').find('div').append('<span class="sd2-number sd2-custom-title-font">' + ( index + 1 ) + '</span>');
                        $(this).find('.sd2-number').css({
                            'line-height': 65 + 'px',
                            'font-size': ( 20 ) + 'px'
                        });
                        /*
                        if( slidedeck_ie <= 8.0 ){
                            $(this).find('div')[0].style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + image + "', sizingMethod='scale')";
                        }else{
                            $(this).find('div').css('background-image', 'url(' + image + ')' )
                        }
                        */
                    }
                });
                
                /**
                 * Add a class to see when the mouse is in the slide area
                 * 
                 * The basic idea is that if the user's mouse is in the button nav
                 * area then we can reasonably assume they are about to click either the
                 * prev/next page button or a button. In this case, we skip auto scrolling.
                 */
                slidedeckFrame.find('.button-nav').bind('mouseenter mouseleave', function(event){
                    if( event.type == 'mouseenter' ){
                        mouseIsHoveringOverNav = true;
                    }else{
                        mouseIsHoveringOverNav = false;
                    }
                });
                
                // Bind click events to the prev/next arrows
                slidedeckFrame.find('.button-nav .nav-arrow').bind('click', function(event){
                    event.preventDefault();
                    switch( this.hash ){
                        case '#prev-page':
			    
                            navDeck.prev();
                        break;
                        case '#next-page':
			
                            navDeck.next();
                        break;
                    }
                });
                
                self.syncButtonTextNavigation();
            }
        }
        /**
         * Keeps the button text navigation SlideDeck below the main deck
         * in sync with the current slide. Has an exception for when the user
         * is hovering the mouse over the secondary deck nav.
         */
        this.syncButtonTextNavigation = function(){
            if( navDeck ){
                if( !mouseIsHoveringOverNav ){
                    var slideIsOnPage = Math.ceil( deck.current / maxButtonsPerPage );

		    
                    navDeck.goTo( slideIsOnPage );
                    
                }
            }
        }


        
        /**
         * Navigation function for the deck (when using thumbnail buttons)
         * 
         * Do not modify these values. If you must mess with them, they are
         * all set near the top of this class.
         */
        this.buttonNavigation = function(){

            if( slidedeckFrame.hasClass('sd2-nav-thumbnails') ) {
                var slideCount = slidedeck.find('dd.slide').length;
                var navHtml = '<div class="button-nav"></div>';
                var appendedNav = $(navHtml).appendTo(slidedeckFrame);
                var navOuterWidth = parseInt( appendedNav.outerWidth() );
               
                var navArrowWidth = 34;
                var buttonsMargin = navArrowWidth + Math.round( thumbnailSpacing / 2 );
                var maxButtonsPerPage = 5;
                
                numberOfPages = Math.ceil( slideCount / maxButtonsPerPage );
                
                // If there's only one slide, don't do any thumbnails.
                if( slideCount < 2 ) return true;
                
                detectedIntrinsicHeight = slidedeckFrame[0].className.match(/sd2-thumbnail-height-([0-9]+)/);
                if( typeof(detectedIntrinsicHeight[1]) != 'undefined' ) {
                    thumbnailPercentageIntrinsic = parseInt( detectedIntrinsicHeight[1] );
                }
                
                if( maxButtonsPerPage >= slideCount ){
                    navArrowWidth = false;
                }
                
                // Create the button nav
                var buttonNav = slidedeckFrame.find('.button-nav');
                
                // Append the previous nav
                if( navArrowWidth ){
                    buttonNav.append('<a class="nav-arrow prev" href="#prev-page" style="width:' + navArrowWidth + 'px;"><span></span></a>');
                } else {
                    buttonsMargin = 0;
                }
                
                // Create the pages
                var indexCount = 0;
                buttonNav.append('<dl class="nav-slidedeck" style="width: auto; margin: 0 ' + ( buttonsMargin - Math.round( thumbnailSpacing / 2 ) ) + 'px;"></dl>');
                navDeckElement = slidedeckFrame.find('dl.nav-slidedeck');
                for( p = 1; p <= numberOfPages; p++ ){
                    
                    navDeckElement.append( '<dd class="sd-page"></dd>' );
                    var thisPage = slidedeckFrame.find('dl.nav-slidedeck dd:eq(' + ( p - 1 ) + ')');
                    
                    for( i = indexCount; i < Math.min( slideCount, maxButtonsPerPage ) * p; i++ ) {
                        var thumbnail = '<span class="nav-button"><div style="padding-top:' + thumbnailPercentageIntrinsic + '%; margin: 0 ' + Math.round( thumbnailSpacing / 2 ) + 'px">Foo</div></span>';
                        if( indexCount >= slideCount ) {
                            thumbnail = false;
                        }
                        
                        if( thumbnail ){
                            $( thumbnail ).appendTo(thisPage);
                        }else{
                            $( '<span class="spacer"></span>' ).appendTo(thisPage);
                        }
                        
                        indexCount++;
                    }
                }
                
                /**
                 * Figure out the height of one thumbnail item, and then
                 * set the height of the nav deck.
                 */
                var thumbnailHeight = Math.round( parseInt( buttonNav.find('.nav-button:first div').css('padding-top') ) );
                navDeck = slidedeckFrame.find('dl.nav-slidedeck').css({
                    height: thumbnailHeight
                }).slidedeck({
                    keys: false,
                    scroll: false,
                    cycle: slidedeck.slidedeck().options.cycle
                });
                
                // Adjust the deck height based on the thumbnail navigation height.
                deckHeightAdjustment = thumbnailHeight + thumbnailSpacing;
                slidedeck.css({
                    height: slidedeck.height() - deckHeightAdjustment
                });
                slidedeck.find('dd').css({
                    height: slidedeck.height()
                });
                
                
                var buttons = buttonNav.find('.nav-button');
                
                // Append the next nav
                if( navArrowWidth ) {
                    buttonNav.append('<a class="nav-arrow next" href="#next-page" style="width:' + navArrowWidth + 'px;"><span></span></a>');
                }
                
                buttons.eq( deck.current-1 ).addClass('active');
                
                buttons.bind('click', function(){
                    var $self = $(this);
                    deck.goTo( ($self).index('.nav-button') +1 );
                });
                
                // Size the buttons appropriately.
                buttons.css({
                    width: ( 100 / ( Math.min( slideCount, maxButtonsPerPage ) ) ) + '%'
                });
                navDeckElement.find('span.spacer').css({
                    width: ( 100 / ( Math.min( slideCount, maxButtonsPerPage ) ) ) + '%'
                });
                
                // Only for IE - detect background image url and update style for DD element
                buttons.each(function( index ){
                    var image = true;
                    if( deck.slides.eq( index ).attr('data-thumbnail-src') ){
                        /**
                         * Use a large image if the thumbnail size is larger than the
                         * defined size. This is for speed and clarity :-)
                         */
                    			console.log("hello");
                            image = deck.slides.eq( index ).attr('data-thumbnail-src');
                       
                    }
                    
                    if( !image ) {
			
                        $(this).addClass('sd2-no-image').find('div').append('<span class="sd2-number sd2-custom-title-font">' + ( index + 1 ) + '</span>');
                        $(this).find('.sd2-number').css({
                            'line-height': thumbnailHeight + 'px',
                            'font-size': ( thumbnailHeight * 0.75 ) + 'px'
                        });
                    } else {
                        if( slidedeck_ie <= 8.0 ){
                            $(this).find('div')[0].style.filter = "progid:DXImageTransform.Microsoft.AlphaImageLoader(src='" + image + "', sizingMethod='scale')";
                        }else{
                            $(this).find('div').css('background-image', 'url(' + image + ')' )
                        }
                    }
                });
                
                /**
                 * Add a class to see when the mouse is in the slide area
                 * 
                 * The basic idea is that if the user's mouse is in the button nav
                 * area then we can reasonably assume they are about to click either the
                 * prev/next page button or a button. In this case, we skip auto scrolling.
                 */
                slidedeckFrame.find('.button-nav').bind('mouseenter mouseleave', function(event){
                    if( event.type == 'mouseenter' ){
                        mouseIsHoveringOverNav = true;
                    }else{
                        mouseIsHoveringOverNav = false;
                    }
                });
                
                // Bind click events to the prev/next arrows
                slidedeckFrame.find('.button-nav .nav-arrow').bind('click', function(event){
                    event.preventDefault();
                    switch( this.hash ){
                        case '#prev-page':
                            navDeck.prev();
                        break;
                        case '#next-page':
                            navDeck.next();
                        break;
                    }
                });
                
                self.syncButtonNavigation();
            }
        }
        
        /**
         * Keeps the button navigation SlideDeck below the main deck
         * in sync with the current slide. Has an exception for when the user
         * is hovering the mouse over the secondary deck nav.
         */
        this.syncButtonNavigation = function(){
            if( navDeck ){
                if( !mouseIsHoveringOverNav ){
                    var slideIsOnPage = Math.ceil( deck.current / maxButtonsPerPage );
                    navDeck.goTo( slideIsOnPage );
                }
            }
        }
        
        /**
         * Compensates the navigation arrows by shifting them upwards
         * the same pixel value as the height of the navigation. The resulting 
         * height makes the arrows appear to be centered with the deck element.
         */
        this.shiftNavButtons = function(){
            slidedeckFrame.find('.deck-navigation.horizontal').each(function(){
                $(this).css({
                    'margin-top': parseInt( $(this).css('margin-top') ) - ( deckHeightAdjustment / 2 )
                });
            });
        }
        
        /**
         * Calculates the width of the date text, which is actually
         * being displayed as the center cell of a table. If the center
         * cell has a width defined, the other neighbors will stretch and
         * that's how the lines effect is done. It's verbose in the HTML but it works.
         */
        this.sizeDateLines = function(){
            var dateWrapperWidth = slidedeckFrame.find('.sd2-slide-date-wrapper').width();
            var dateText = slidedeckFrame.find('.sd2-slide-date-wrapper .sd2-slide-date');
            var dateTextWidth = dateText.width();
            
            // Take a measurement on the date text while it's still an inline element...
            var dateTextPercent = Math.ceil( ( dateTextWidth / dateWrapperWidth ) * 100 ) * 1.2;
            
            // Set the date text to a percent, and display table cell
            dateText.css({
                'display': 'table-cell',
                'width': dateTextPercent + '%'
            });
        }
                
        // Get the old complete option
        var oldComplete = deck.options.complete;
        
        deck.setOption('complete', function(){
            // If the old complete option was a function, run it
            if(typeof(oldComplete) == 'function') {
                oldComplete(deck);
            }
        });
        
        var oldBefore = deck.options.before;
	
        deck.setOption('before', function(deck){
            if($('.slidedeck-frame').contents().find('.sd2-slide-titles-inner').hasClass(titleClasses[2]))            
            	$('.slidedeck-frame').contents().find('.sd2-slide-titles-inner').removeClass(titleClasses[2]);
            if(typeof(oldBefore) == 'function')
               oldBefore(deck);
            
            // Bind the callbacks to the dot nav
            if( slidedeckFrame.hasClass('sd2-nav-dots') ){
                var navDots = slidedeckFrame.find('.dot-nav').find('li');
                navDots.removeClass('accent-color-background active');
                navDots.eq(deck.current-1).addClass('accent-color-background active');
            }
            
            var navButtons = slidedeckFrame.find('.button-nav').find('.nav-button');
            // Bind the callbacks to the nav buttons (thumbnails)
            if( slidedeckFrame.hasClass('sd2-nav-thumbnails') ){
                navButtons.removeClass('active');
                navButtons.eq(deck.current-1).addClass('active');
            }

            var navTextButtons = slidedeckFrame.find('.button-nav').find('.nav-button');
            // Bind the callbacks to the nav buttons (text)
            if( slidedeckFrame.hasClass('sd2-nav-text') ){
                navTextButtons.removeClass('active');
                navTextButtons.eq(deck.current-1).addClass('active');
            }

            $('.slidedeck-frame').contents().find('.sd2-slide-titles-inner').addClass(titleClasses[2]);
            self.syncButtonNavigation();
        });
        
        this.dotNavigation();

           this.buttonNavigation();
        this.buttonTextNavigation();
        this.shiftNavButtons();
        this.sizeDateLines();
        return true;
    };
    
    $(document).ready(function(){
        $('.lens-titles .slidedeck').each(function(){
            if(typeof($.data(this, 'lens-titles')) == 'undefined'){
                $.data(this, 'lens-titles', new SlideDeckLens['titles'](this));
            }
        });
        // for title transition effects to stop on each slide - code added by Dhananjay M.
        $('.sd2-slide-titles-inner').on('animationiteration', function() {
        	
		$('.slidedeck-frame').contents().find('.sd2-slide-titles-inner').removeClass(titleClasses[2]);
		//$('.slidedeck-frame').contents().find('.sd2-slide-title-inner').addClass(titleClasses[2]);
        });

        
        //$('.content-source-custom .button-nav .nav-slidedeck .sd2-no-image .sd2-custom-title-font a').removeClass('accent-color');


    });
    
})(jQuery);
